import matplotlib.pyplot as plt
from experiment_class import Experiment


def plot_flower(experiment: Experiment):
    """
    Description
    -----------
    plots the flower of an experiment, a circle with seeds within 

    Parameters
    ---------
    experiment: Experiment 
        Experiment class instance with seed_data 
    """
    
    from load_config import load_config
    root_path = load_config()['plot_save_path']

    name = f'{experiment.alias}-{experiment.a},{experiment.b}-{experiment.step_size}-{experiment.experiment_type}.svg'
    path = f'{root_path}/flowerPlots/{name}'

    fig,ax = plt.subplots()

    ax.set_ylim(-experiment.get_max_radius() * 1.1, experiment.get_max_radius() * 1.1)
    ax.set_xlim(-experiment.get_max_radius() * 1.1, experiment.get_max_radius() * 1.1)

    ax.set_aspect('equal',adjustable='box')
    ax.set_axis_off()

    ax.add_patch(plt.Circle((0,0),experiment.get_max_radius(),fill=False,color='k'))
    for seed in experiment.get_seed_data(): 
        ax.add_patch(plt.Circle((seed["x"],seed["y"]), 1,  fill=True, color='k'))

    plt.savefig(path)



import matplotlib.pyplot as plt
import os 
import numpy as np
from .experiment_class import Experiment


def plot_heatmap(data:list[list[float]], experiment: Experiment):
    from load_config import load_config
    root_path = load_config()["plot_save_path"]

    #save dir
    name = f'{len(data[0])}-{experiment.get_experiment_type()}.svg'
    path = f'{root_path}/heatmaps/{name}'
    os.makedirs(os.path.dirname(path), exist_ok=True)
    
    #heatmap
    plt.imshow(data, cmap='inferno', interpolation='none', origin='lower')

    #ticks 
    num_ticks = len(data[0])
    ticks = list(range(1, num_ticks + 1))    
    plt.xticks(ticks=np.arange(num_ticks), labels=ticks, rotation=-90,fontsize=4)
    plt.yticks(ticks=np.arange(num_ticks), labels=ticks, rotation=0,fontsize=4)

    #title
    plt.title(f'{experiment.get_experiment_type()}, {len(data[0])}x{len(data[0])}')

    plt.savefig(path)